@@ -9,7 +9,7 @@ use Forks::Super::Debug qw(debug);
 use Forks::Super::Util qw(is_number qualify_sub_name shquote
                           IS_CYGWIN IS_WIN32 is_pipe);
 use Forks::Super::Config qw(:all);
-use Forks::Super::Job::Ipc;   # does windows prefer to load Ipc before Timeout?
+use Forks::Super::Job::Ipc;
 use Forks::Super::Job::Timeout;
 use Forks::Super::Deferred qw(queue_job);
 use Forks::Super::Job::OS;
@@ -23,10 +23,11 @@ use IO::Handle;
 use strict;
 use warnings;
 
+
 our @ISA = qw(Exporter);
 our @EXPORT = qw(@ALL_JOBS %ALL_JOBS PREFORK POSTFORK 
                  POSTFORK_PARENT POSTFORK_CHILD);
-our $VERSION = '0.88';
+our $VERSION = '0.89';
 
 our (@ALL_JOBS, %ALL_JOBS, @ARCHIVED_JOBS, $WIN32_PROC, $WIN32_PROC_PID);
 our $OVERLOAD_ENABLED = 0;
@@ -649,6 +650,12 @@ sub _postlaunch_parent1 {
 	#
 	Forks::Super::Sigchld::handle_bastards($pid);
     }
+    if ($job->{signal_ipc_pipe}) {
+        close $job->{signal_ipc_pipe}[1];
+    }
+    if ($job->{daemon_ipc_pipe}) {
+        close $job->{daemon_ipc_pipe}[1];
+    }
     if ($job->{daemon}) {
 	$pid = $job->_postlaunch_daemon_parent($pid);
     }
@@ -658,20 +665,6 @@ sub _postlaunch_parent1 {
 
     $job->_config_parent(1);
     return;
-    $job->run_callback('start');
-
-    Forks::Super::handle_CHLD(-1);
-    if ($$ != $Forks::Super::MAIN_PID) {
-	# Forks::Super::fork call from a child.
-	$XSIG{CHLD}[-1] ||= \&Forks::Super::handle_CHLD;
-    }
-    if ($^O eq 'MSWin32') {
-	if ($job->{timeout} || $job->{expiration}) {
-	    $job->_read_signal_pid;
-	}
-    }
-
-    return $OVERLOAD_ENABLED ? $job : $pid;
 }
 
 sub _postlaunch_parent2 {
@@ -683,11 +676,7 @@ sub _postlaunch_parent2 {
 	# Forks::Super::fork call from a child.
 	$XSIG{CHLD}[-1] ||= \&Forks::Super::handle_CHLD;
     }
-    if ($^O eq 'MSWin32') {
-	if ($job->{timeout} || $job->{expiration}) {
-	    $job->_read_signal_pid;
-	}
-    }
+    $job->_read_signal_pid;
     return $OVERLOAD_ENABLED ? $job : $job->{pid};
 }
 
@@ -1244,7 +1233,7 @@ sub __build_ssh_command {
     # once for the remote shell interpreting the command
 
     if (@{$job->{cmd}} <= 1) {
-        push @cmd, map { shquote2($_) } @{$job->{cmd}};
+        push @cmd, map { shquote($_) } @{$job->{cmd}};
     } else {
         push @cmd, map { shquote2($_) } @{$job->{cmd}};
     }
@@ -1270,8 +1259,11 @@ sub __build_ssh_command {
     }
 
     if ($job->{fh_config}{out}) {
-        close STDOUT;
-        push @cmd, ">" . shquote($job->{fh_config}{f_out});
+        if ($job->{fh_config}{f_out} eq '__socket__') {
+        } else {
+            close STDOUT;
+            push @cmd, ">" . shquote($job->{fh_config}{f_out});
+        }
     } else {
         push @cmd, ">/dev/null";
     }
@@ -1421,7 +1413,7 @@ sub signal_pid {
     my $job = shift;
 
     if (($job->{signal_ipc} || $job->{signal_ipc_pipe}) &&
-            !defined $job->{signal_pid}) {
+        !defined $job->{signal_pid}) {
 	$job->_read_signal_pid;
     }
     if ($job->{debug} && defined $job->{signal_pid}) {
@@ -1444,10 +1436,11 @@ sub __read_from_pipe {
             my $ch;
             for (;;) {
                 $ch = getc($pipe);
-                last if !defined($ch) || $ch eq "\n";
+                if (!defined($ch) || $ch eq "\n") {
+                    return $line;
+                }
                 $line .= $ch;
             }
-            return $line;
         }
     }
     return;
@@ -1469,6 +1462,7 @@ sub _read_signal_pid {
                 debug('parent forwarding signals for ', 
                       $job->{real_pid}, ' to ', $job->{signal_pid});
             }
+            delete $job->{signal_ipc_pipe};
             return;
         } elsif ($job->{debug}) {
             debug('no signal pid read from signal ipc pipe ...');
@@ -1482,7 +1476,7 @@ sub _read_signal_pid {
             Forks::Super::Util::pause(0.002*$try*$try*$try, $try<3);
         }
     }
-    if (-f $job->{signal_ipc}) {
+    if ($job->{signal_ipc} && -f $job->{signal_ipc}) {
 	for my $try (1..2) {
 	    if (open my $fh, '<', $job->{signal_ipc}) {
 		my $signal_pid = <$fh>;
@@ -1490,7 +1484,6 @@ sub _read_signal_pid {
 		unlink $job->{signal_ipc} or
 		    warn 'parent did not remove IPC signal file ',
 		         $job->{signal_ipc}, "! $!";
-		# delete $job->{signal_ipc};
 		($job->{signal_pid}) = $signal_pid =~ /([-\d]*)/;
 		if ($^O eq 'MSWin32') {
 		    $job->{pgid} = $job->{signal_pid};
@@ -1499,6 +1492,7 @@ sub _read_signal_pid {
 		    debug('parent forwarding signals for ', 
 			  $job->{real_pid}, ' to ', $job->{signal_pid});
 		}
+                delete $job->{signal_ipc};
 		last;
 	    } else {
 		Forks::Super::pause(1.0);
@@ -1711,7 +1705,7 @@ sub _preconfig2 {
             }
         }
     }
-    if ($job->{style} eq 'cmd' 
+    if ($job->{style} eq 'cmd'
 		|| (&IS_WIN32 && $job->{style} eq 'exec')
 		|| (&IS_WIN32 && ($job->{timeout} || $job->{expiration}))) {
 
@@ -2577,7 +2571,7 @@ Forks::Super::Job - object representing a background task
 
 =head1 VERSION
 
-0.88
+0.89
 
 =head1 SYNOPSIS
 
