@@ -33,7 +33,7 @@ $| = 1;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(close_fh);
-our $VERSION = '0.88';
+our $VERSION = '0.89';
 our $NO_README = 0;
 
 our (%FILENO, %SIG_OLD, $IPC_COUNT, $IPC_DIR_DEDICATED,
@@ -592,6 +592,11 @@ sub Forks::Super::Job::_preconfig_fh {
 
     # set  %$config{in,out,err,join,block,sockets,pipes}
     my $config = _preconfig_fh_parse_child_fh($job);
+    if ($job->{remote} && ($config->{sockets} || $config->{pipes}) &&
+        !Forks::Super::Config::CONFIG_module("Net::OpenSSH")) {
+        carp "Forks::Super::fork: child_fh => socket|pipe is not compatible ",
+                "with 'remote' option";
+    }
 
     # set  %$config{stdin,stdout,stderr}
     _preconfig_fh_parse_stdxxx($job, $config);
@@ -998,7 +1003,7 @@ sub _identify_shared_fh_dir {
 	    'E:/Windows/Temp', 'E:/Winnt/Temp', '.';
     } else {
 	my ($cwd) = Forks::Super::Util::abs_path('.') =~ /(.*)/;
-	unshift @search_dirs, $cwd;
+	unshift @search_dirs, '/dev/shm', $cwd;
 	push @search_dirs, '/tmp', '/var/tmp', '/usr/tmp';
     }
 
@@ -1875,16 +1880,15 @@ sub __config_fh_parent_stderr_file {
 # the same files at about the same time.
 #
 sub Forks::Super::Job::_config_fh_parent {
-    my $job = shift;
+    my ($job,$step) = @_;
     return if not defined $job->{fh_config};
-    my $step = shift || 0;
-
-    # _trap_signals(); # XXX - is this necessary?
     my $fh_config = $job->{fh_config};
 
-    # set up stdin first.
-    _config_fh_parent_stdin($job) if $step != 2;
-    return if $step == 1;
+    # set up stdin first, so child has more time to set up stdout and stderr
+    if ($step != 2) {
+        _config_fh_parent_stdin($job);
+        return;
+    }
     _config_fh_parent_stdout($job);
     _config_fh_parent_stderr($job);
 
@@ -3381,7 +3385,7 @@ Forks::Super::Job::Ipc - interprocess communication routines for Forks::Super
 
 =head1 VERSION
 
-0.88
+0.89
 
 =head1 DESCRIPTION
 
