@@ -11,7 +11,7 @@ use warnings;
 
 our @ISA = qw(Exporter);
 our @EXPORT = qw(bg_eval bg_qx BG_EVAL BG_QX);
-our $VERSION = '0.88';
+our $VERSION = '0.89';
 
 use constant BG_EVAL => 'Forks::Super::bg_eval';
 use constant BG_QX   => 'Forks::Super::bg_qx';
@@ -187,7 +187,8 @@ sub bg_qx {
 	my ($this,$count) = @_;
 	my $array = $this->array;
 	if (@$array < $count) {
-	    push @$array, (undef) x (@$array-$count);
+	    push @$array, (undef) x ($count-@$array);
+#	    push @$array, (undef) x (@$array-$count);
 	} else {
 	    pop @$array while @$array > $count;
 	}
@@ -336,7 +337,7 @@ Forks::Super::LazyEval
 
 =head1 VERSION
 
-0.88
+0.89
 
 =head1 DESCRIPTION
 
